========
MagmaPEC
========
MagmaPEC is a flexible model for correcting olivine-hosted melt inclusions for the effects of post-entrapment crystallisation (PEC) or melting.

Documentation
-------------
Code documentation is currently being worked on at `magmapec.readthedocs.io <https://magmapec.readthedocs.io>`_


How to cite MagmaPandas
------------------------------
If have used MagmaPandas in your research, please reference  `this paper <placeholder>`_ . To ensure reproducibility, please also mention the release version of MagmaPEC and reference the specific models you used (see `documentation <https://magmapandas.readthedocs.io/en/latest/code_documentation.html#references>`_).


Installation
------------
MagmaPEC can be installed with pip by running:

.. code-block:: bash

    pip install magmapec

in a terminal.
If you want to install from a specific git branch or release, use:

.. code-block:: bash

    pip install git+https://github.com/TDGerve/MagmaPEC.git@tag

where *tag* should be repleaced by the release tag or branch name (e.g. *v1.0.0* or *development*)





